@@ -15,6 +15,8 @@ use Class::XSAccessor
         directory =>'directory',
         filters => 'filters',
         format_spec => 'format_spec',
+	files=>'files',
+	suggest_stanzas=> 'suggest_stanzas',
     },
 ;
 use File::Slurp;
@@ -94,6 +96,14 @@ sub _build_file_mapping {
     my $copyright_target = shift;
     my $file_mapping = $copyright_target->map_directory($self->directory);
 
+    if ($self->files) {
+	foreach my $key (keys %$file_mapping) {
+	    if (not exists $self->files->{$key}) {
+		delete $file_mapping->{$key};
+            }
+	}
+    }
+
     if ($self->display_mapping) {
         foreach my $file (sort keys %$file_mapping) {
             print "$file: $file_mapping->{$file}->{pattern}\n";
@@ -109,6 +119,7 @@ sub run {
     Readonly my $CONFIG => $self->_parse_config;
     Readonly my $LICENSECHECK => $self->_build_licensecheck($CONFIG);
     Readonly my $COPYRIGHT_TARGET => $self->_read_copyright_file;
+    my $file_checked = {};
     if ($COPYRIGHT_TARGET) {
 
         Readonly my $FILE_MAPPING => $self->_build_file_mapping($COPYRIGHT_TARGET);
@@ -116,7 +127,6 @@ sub run {
             Debian::LicenseReconcile->new(
                 $COPYRIGHT_TARGET->patterns($self->check_copyright)
             );
-        my $file_checked = {};
         foreach my $filter_name (@{$self->filters}) {
             $file_checked = $self->_run_filter(
                 $filter_name,
@@ -130,6 +140,30 @@ sub run {
         }
 
     }
+
+    if ($self->suggest_stanzas) {
+	foreach my $f (sort keys %$file_checked) {
+		print "Files: $f\n";
+		if ($self->check_copyright) {
+            if (not ref $file_checked->{$f}->{copyright}) {
+                print "Copyright: $file_checked->{$f}->{copyright}\n";
+                next;
+            }
+			my @copyright = @{$file_checked->{$f}->{copyright}};
+			if (1 == scalar @copyright) {
+				print "Copyright: $copyright[0]\n";
+			}
+			else {
+				foreach my $line (@copyright) {
+					print " $line\n";
+				}
+			}
+		}
+		print "License: $file_checked->{$f}->{license}\n";
+		print "\n";
+	}
+    }
+
     return $self->_report_errors;
 }
 
@@ -162,7 +196,8 @@ sub _run_filter {
     );
     foreach my $titbit ($test->get_info) {
         next if $file_checked->{$titbit->{file}};
-        $file_checked->{$titbit->{file}} = 1;
+	next if $self->files and not exists $self->files->{$titbit->{file}};
+        $file_checked->{$titbit->{file}} = $titbit;
         if (exists $file_mapping->{$titbit->{file}}) {
             $reconcile->check(
                 $titbit,
@@ -209,11 +244,11 @@ Debian::LicenseReconcile::App - encapsulate the application code
 
 =head1 VERSION
 
-Version 0.7
+Version 0.9
 
 =cut
 
-our $VERSION = '0.7';
+our $VERSION = '0.9';
 
 
 =head1 SYNOPSIS
@@ -232,6 +267,8 @@ object.
 
 =head2 run
 
+This contains the core logic of the tool.
+
 =head2 quiet
 
 =head2 display_mapping
@@ -250,13 +287,15 @@ object.
 
 =head2 format_spec
 
+=head2 files
+
 =head1 AUTHOR
 
 Nicholas Bamber, C<< <nicholas at periapt.co.uk> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012 Nicholas Bamber C<< <nicholas at periapt.co.uk> >>.
+Copyright 2012, 2015, Nicholas Bamber <nicholas at periapt.co.uk> .
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
